@@ -1,4 +1,5 @@
 import abc
+from functools import partial
 from typing import List, Optional, Union
 
 import numpy as np
@@ -24,6 +25,13 @@ except AttributeError:
         return _broadcast_shape(*[np.empty(x, dtype=[]) for x in shapes])
 
 
+def get_partial_wrapper(rv, name, *args, **kwargs):
+    func = partial(rv, *args, **kwargs)
+    func.__name__ = name
+    func.__module__ = rv.__module__
+    return func
+
+
 class ScipyRandomVariable(RandomVariable):
     r"""A class for straightforward `RandomVariable`\s that use SciPy-based samplers.
 
@@ -267,6 +275,90 @@ class RayleighRV(RandomVariable):
 rayleigh = RayleighRV()
 
 
+class PowerRV(RandomVariable):
+    r"""A power continuous random variable.
+
+    The probability density function for `power` is:
+
+    .. math::
+
+        P(x; a) = ax^{a-1}, 0 \\le x \\le 1, a>0.
+
+    """
+    name = "power"
+    ndim_supp = 0
+    ndims_params = [0]
+    dtype = "floatX"
+    _print_name = ("Power", "\\operatorname{Power}")
+
+    def __call__(self, a, size=None, **kwargs):
+        r"""Draw samples from a rayleigh distribution.
+
+        Signature
+        ---------
+
+        `() -> ()`
+
+        Parameters
+        ----------
+        a
+            Parameter of the distribution. Must be non-negative.
+        size
+            Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n * k`
+            independent, identically distributed random variables are
+            returned. Default is `None` in which case a single random variable
+            is returned.
+
+        """
+        return super().__call__(a, size=size, **kwargs)
+
+
+power = PowerRV()
+
+
+class ZipfRV(RandomVariable):
+    r"""A zipf discrete random variable.
+
+    The probability density function for `zipf` is:
+
+    .. math::
+
+        p(x) = \\frac{x^{-a}}{\\zeta(a)},
+
+    where :math:`\\zeta` is the Riemann Zeta function.
+
+    """
+    name = "zipf"
+    ndim_supp = 0
+    ndims_params = [0]
+    dtype = "int64"
+    _print_name = ("Zipf", "\\operatorname{Zipf}")
+
+    def __call__(self, a, size=None, **kwargs):
+        r"""Draw samples from a rayleigh distribution.
+
+        Signature
+        ---------
+
+        `() -> ()`
+
+        Parameters
+        ----------
+        a
+            Distribution parameter. Must be greater than 1.
+        size
+            Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n * k`
+            independent, identically distributed random variables are
+            returned. Default is `None` in which case a single random variable
+            is returned.
+
+        """
+        return super().__call__(a, size=size, **kwargs)
+
+
+zipf = ZipfRV()
+
+
 class NormalRV(RandomVariable):
     r"""A normal continuous random variable.
 
@@ -311,40 +403,7 @@ class NormalRV(RandomVariable):
 
 
 normal = NormalRV()
-
-
-class StandardNormalRV(NormalRV):
-    r"""A standard normal continuous random variable.
-
-    The probability density function for `standard_normal` is:
-
-    .. math::
-
-        f(x) = \frac{1}{\sqrt{2 \pi}} e^{-\frac{x^2}{2}}
-
-    """
-
-    def __call__(self, size=None, **kwargs):
-        """Draw samples from a standard normal distribution.
-
-        Signature
-        ---------
-
-        `nil -> ()`
-
-        Parameters
-        ----------
-        size
-            Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n * k`
-            independent, identically distributed random variables are
-            returned. Default is `None` in which case a single random variable
-            is returned.
-
-        """
-        return super().__call__(loc=0.0, scale=1.0, size=size, **kwargs)
-
-
-standard_normal = StandardNormalRV()
+standard_normal = get_partial_wrapper(normal, "standard_normal", loc=0.0, scale=1.0)
 
 
 class HalfNormalRV(ScipyRandomVariable):
@@ -511,6 +570,7 @@ class GammaRV(ScipyRandomVariable):
 
 
 gamma = GammaRV()
+standard_gamma = get_partial_wrapper(gamma, "standard_gamma", rate=1.0)
 
 
 class ChiSquareRV(RandomVariable):
@@ -718,6 +778,9 @@ class ExponentialRV(RandomVariable):
 
 
 exponential = ExponentialRV()
+standard_exponential = get_partial_wrapper(
+    exponential, "standard_exponential", scale=1.0
+)
 
 
 class WeibullRV(RandomVariable):
@@ -930,7 +993,6 @@ class MvNormalRV(RandomVariable):
 
     @classmethod
     def rng_fn(cls, rng, mean, cov, size):
-
         if mean.ndim > 1 or cov.ndim > 2:
             # Neither SciPy nor NumPy implement parameter broadcasting for
             # multivariate normals (or any other multivariate distributions),
@@ -1205,6 +1267,7 @@ class CauchyRV(ScipyRandomVariable):
 
 
 cauchy = CauchyRV()
+standard_cauchy = get_partial_wrapper(cauchy, "standard_cauchy", loc=0.0, scale=1.0)
 
 
 class HalfCauchyRV(ScipyRandomVariable):
@@ -1464,6 +1527,7 @@ class StudentTRV(ScipyRandomVariable):
 
 
 t = StudentTRV()
+standard_t = get_partial_wrapper(t, "standard_t", loc=0.0, scale=1.0)
 
 
 class BernoulliRV(ScipyRandomVariable):
@@ -2095,7 +2159,6 @@ class PermutationRV(RandomVariable):
         return rng.permutation(x if x.ndim > 0 else x.item())
 
     def _infer_shape(self, size, dist_params, param_shapes=None):
-
         param_shapes = param_shapes or [p.shape for p in dist_params]
 
         (x,) = dist_params
@@ -2167,10 +2230,16 @@ __all__ = [
     "beta",
     "triangular",
     "uniform",
+    "standard_cauchy",
+    "standard_exponential",
+    "standard_gamma",
     "standard_normal",
+    "standard_t",
     "negative_binomial",
     "gengamma",
     "t",
     "random",
     "rayleigh",
+    "power",
+    "zipf",
 ]
